@@ -5,7 +5,7 @@ use warnings;
 package Mite;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.010004';
+our $VERSION   = '0.010005';
 
 1;
 
@@ -23,27 +23,36 @@ Start a project:
 
     $ mite init Foo
 
-Write a class:
+Write a class (F<lib/Foo.pm>):
 
-    $ cat lib/Foo.pm
     package Foo;
     
-    # Load the Mite shim
     use Foo::Mite;
     
-    # Subclass of Bar
-    extends "Bar";
-    
-    # A read/write string attribute
     has attribute => (
         is      => 'rw',
     );
     
-    # A read-only attribute with a default
     has another_attribute => (
         is      => 'ro',
-        default => 1,
+        default => 'Hello world',
     );
+    
+    1;
+
+Write another class (F<lib/Foo/Bar.pm>):
+
+    package Foo::Bar;
+    
+    use Foo::Mite;
+    extends 'Foo';
+    
+    sub my_method {
+        my $class = shift;
+        print $class->new->another_attribute, "\n";
+    }
+    
+    1;
 
 Compile your project:
 
@@ -51,7 +60,7 @@ Compile your project:
 
 Use your project:
 
-    $ perl -Ilib -MFoo -E'say Foo->new->another_attribute'
+    $ perl -Ilib -MFoo::Bar -E'Foo::Bar->my_method'
 
 =head1 DESCRIPTION
 
@@ -76,7 +85,7 @@ Mite writes pure Perl code and your module will run with no
 dependencies.  It will also write code to use other, faster modules to
 do the same job, if available.
 
-These optimizations can be turned off by setting the C<MITE_PURE_PERL>
+These optimizations can be turned off by setting the C<PERL_ONLY>
 environment variable true.
 
 You may wish to add these as recommended dependencies.
